Skip to contents

A tibble containing the General Social Survey Cumulative Data file.

Usage

data(gss_all)

Format

An object of class tibble with 75,699 rows and 6,942 columns. Variables are encoded as labelled vectors. The GSS Codebook is the authoritative source for the variables in this dataset. It is available at http://gss.norc.org/Get-Documentation. Summary information is available in gss_doc, a tibble supplied with this package.

National Opinion Research Center, http://gss.norc.org.

Details

This is Release 3 of the 1972-2024 GSS cumulative data file. See the release notes and documentation from NORC. for further details.