A tibble containing information on the variables in the GSS Cumulative Data File.
data(gss_doc)A tibble.
idThe short name of the variable. A character vector.
descriptionBrief description of the variable. A character vector.
propertiesA list column containing information on the variable's data type, its missing value codes, and its record/column location.
marginalsA list column containing a summary of the values taken by the variable.
textFurther more detailed information on the question asked and the directions provided.
National Opinion Research Center, http://gss.norc.org.